#!/usr/bin/env python

try:
	import simplejson as json
except:
	import json
import sys
from jinja2 import Environment, FileSystemLoader
conversion_map = { 'bool':int, 'int':int, 'std::string':str, 'float':float }

def spring_default_config(input_fn):
	inputdata = json.load(open(input_fn))
	filtered_data = dict()
	for key,value in  inputdata.iteritems():
		try:
			dtype = value['type']
			default = value['defaultValue']
			try:
				filtered_data[key] = conversion_map[dtype](default)
			except KeyError:
				print 'No conversion found for "%s" with type "%s"'%(key,dtype)
		except KeyError,k:
				print 'missing key %s in data for "%s" in file %s:%d'%(k,key,value['declarationFile'],value['declarationLine'])
	return filtered_data

def output(defaults,output_fn):
	env = Environment(loader=FileSystemLoader('.'))
	template = env.get_template('ctrlconstants.h.jinja')
	with open(output_fn,'wb') as outfile:
		outfile.write( template.render(defaults=defaults ) )

if __name__ == '__main__':
	d = spring_default_config( sys.argv[1] )
	output(d,'ctrlconstants.h')


#!/usr/bin/env python

#prints all stable / test tag in a rapid dir

import gzip,sys,os

# returns all stable tags
def getTags(filename):
	tags = {}
	lines = gzip.open(filename).readlines()
	for line in lines:
		line = line.strip("\r\n")
		items = line.split(",")
		if len(items) < 1:
			continue
		tag = items[0]
		if len(tag.split(':')) == 3:
			continue
		tags[items[0]] = items[3]
	return tags

def getfiles(dirname):
	tags = {}
	for f in os.listdir(dirname):
		if f != "versions.gz":
			continue
		filename = os.path.join(dirname, f)
		if os.path.isfile(filename):
			tags.update(getTags(filename))
	return tags

rootdir = sys.argv[1]
tags = {}
for d in os.listdir(rootdir):
	repodir = os.path.join(rootdir, d)
	if os.path.isdir(repodir):
		tags.update(getfiles(repodir))

print("<table>")
print("<tr><td>Tag</td><td>Name</td></tr>")
for tag in sorted(tags.items()):
	print("<tr><td>%s</td><td>%s</td></tr>" %(tag[0], tag[1]))
print("</table>")




#!/usr/bin/python3

import glob, os, time


# delete all builds/*.gz files older than 14 days expect the last three

rootdir = "/home/packages/www/repos.springrts.com"

def sizeof_fmt(num, suffix='B'):
	for unit in ['','Ki','Mi','Gi','Ti','Pi','Ei','Zi']:
		if abs(num) < 1024.0:
			return "%3.1f%s%s" % (num, unit, suffix)
		num /= 1024.0
	return "%.1f%s%s" % (num, 'Yi', suffix)

def CleanupBuilds(now, path):
	files = glob.glob(path + "/*.sdz")
	deleted = 0
	count = 0

	files.sort(key=lambda x: os.path.getmtime(x))
	if len(files) < 3:
		#print("To few files to cleanup for %s" %(path))
		return 0, 0
	#print(path)
	for i in range(0, len(files) - 3):
		filename = files[i]
		if os.path.getmtime(filename) > now - 14 * 86400:
			#print(i, filename, "skipped")
			continue
		print(i, filename, "deleting")
		deleted += os.path.getsize(filename)
		count += 1
		os.unlink(filename)

	#for i in range(len(files) - 3, len(files)):
	#	print(i, files[i], "skipped by count")
	return deleted, count


now = time.time()
paths = glob.glob(rootdir + "/*/builds")

deleted = 0
count = 0
for path in paths:
	tdeleted, tcount = CleanupBuilds(now, path)
	count += tcount
	deleted += tdeleted

if deleted > 0:
	print("Deleted", count, sizeof_fmt(deleted))




#!/usr/bin/python3
import os
import socket
import sys
import time

if len(sys.argv)<2:
	print("Usage: echo msg | %s <channel1> <channel2>" %(sys.argv[0]))
	sys.exit(1)


# comment out to disable
import imp
passwords = imp.load_source("passwords", os.path.join(os.path.dirname(__file__), "passwords.py"))
username = passwords.username
password = passwords.password

channels = set(sys.argv[1:])

buf = ""
template = "JOIN $CHANNEL$\n"
for line in sys.stdin:
	template += "SAY $CHANNEL$ " + line + "\n"
for channel in channels:
	buf += template.replace("$CHANNEL$", channel)
buf += "EXIT Thanks for using rapid! https://github.com/spring/RapidTools\n"

socket = socket.socket()
socket.settimeout(5.0)
socket.connect(('lobby.springrts.com', 8200))

msg = 'LOGIN ' + username + ' ' + password + ' 0 * TASClient 0.33\t0\tcl sp p\n'
socket.sendall(msg.encode())


for i in range(0, 30):
	data = socket.recv(1024).decode()
	if data and data.lower().find("logininfoend") >= 0:
		break

socket.sendall(buf.encode())

time.sleep(1.0)
socket.close()




import os
import json
from lupa import LuaRuntime
from configparser import ConfigParser

def get_remote(repodir):
	configfile = os.path.join(repodir, ".git/config")
	c = ConfigParser()
	c.read(configfile)
	return c.get('remote "origin"', "url")

def get_name(repodir):
	modinfo = os.path.join(repodir, "modinfo.lua")
	lua = LuaRuntime()
	with open(modinfo, "r") as f:
		content = f.read()
		l = lua.execute(content)
		return l["name"]

repolist = {}

for d in os.listdir("/home/packages/git"):
	if not os.path.isdir(d):
		continue
	abspath = os.path.abspath(d)
	reponame = os.path.basename(abspath)
	url = get_remote(abspath)
	name = get_name(abspath)
	assert not reponame in repolist 
	repolist[reponame] = {
		"names": [name],
		"url": url,
		"stablebranch": "master",
		"testbranches": ["master"],
	}


repos = {
	"repos": repolist
}

with open("/home/packages/www/repos.springrts.com/repos.json", "w") as f:
	f.write(json.dumps(repos, indent='\t', sort_keys=True))



#!/usr/bin/python3

# updates repos.gz

import gzip
import os

wwwroot = "/home/packages/www/repos.springrts.com"
prefix = "https://repos.springrts.com/"
streamer = "/home/packages/bin/Streamer"
repos = {
	"main": "https://packages.springrts.com"
}

assert(os.path.isfile(streamer))

def SetupStreamer(repodir):
	streamercgi = os.path.join(repodir, "streamer.cgi")
	if os.path.islink(streamercgi):
		if os.readlink(streamercgi) == streamer:
			return
		print("Deleted invalid link %s" %(streamercgi))
		os.unlink(streamercgi)
	print("Created symlink %s -> %s" %(streamercgi, streamer))
	os.symlink(streamer, streamercgi)


def GetWWWRepos(wwwroot):
	for repo in os.listdir(wwwroot):
		absname = os.path.join(wwwroot, repo)
		if not os.path.isdir(absname):
			continue
		assert(repo not in repos)
		repos[repo] = prefix + repo
	return repos

def ParseRepos(reposgz):
	res = {}
	with gzip.open(os.path.join(wwwroot, "repos.gz"), "rb") as f:
		for line in f.readlines():
			name, url, _, _ = line.decode().split(",", 4)
			res[name] = url
	return res

def WriteRepos(reposgz, repos):
	with gzip.open(reposgz, "wb") as f:
		for reponame, prefix in sorted(repos.items()):
			line = "%s,%s,,\n" %(reponame, prefix)
			f.write(line.encode())

def SetupRepos(wwwroot, wwwrepos):
	for reponame in wwwrepos:
		absdir = os.path.join(wwwroot, reponame)
		if os.path.isdir(absdir):
			SetupStreamer(absdir)

def ReposEqual(repoa, repob):
	for a, b in (repoa, repob), (repob, repoa):
		for k, v in a.items():
			if not k in b:
				return False
			if v != b[k]:
				return False
	return True



reposgz = os.path.join(wwwroot, "repos.gz")
repos.update(GetWWWRepos(wwwroot))

SetupRepos(wwwroot, repos)

currentrepos = ParseRepos(reposgz)

if not ReposEqual(repos, currentrepos):
	print("Updating %s" %(reposgz))
	WriteRepos(reposgz, repos)

assert(ReposEqual(ParseRepos(reposgz), repos))




